# File Converter

Used to convert files to CSV or JSON.

## Introduction

Learning how to deploy a lib on PyPi at PUC using Poetry.



### What this project can do

Read a **CSV** or **JSON** file or a **folder** with files and convert them to **CSV** or **JSON**.

 - If the file was a **CSV** then it will be converted to **JSON**.
 - If the file was a **JSON** then it will be converted to **CSV**.

This project is a program running on terminal, preferably install with pipx:


```bash
pipx install jpaulorc-csv-converter
```

To use, just type in:

```bash
csv_converter --help
```

This will list all available options.